@@ -177,7 +177,8 @@ def update_index_file(temp_dir, target_platform, dependencies, verbose):
         index = json.load(file)
 
     platform, architecture = target_platform.split('-')
-    other_platforms = ['linux-ppc64le', 'linux-armv6l', 'linux-armv7l', 'linux-aarch64']
+    other_platforms = ['linux-ppc64', 'linux-ppc64le', 'linux-s390x',
+                       'linux-armv6l', 'linux-armv7l', 'linux-aarch64']
 
     if target_platform in other_platforms:
         source_architecture = architecture
