@@ -920,7 +920,7 @@ def _lookup_in_sysroots_and_whitelist(errors, whitelist, needed_dso, sysroots_fi
                            format(info_prelude, n_dso_p), verbose=verbose)
                 break
     if not in_whitelist and not in_sysroots:
-        _print_msg(errors, "{}: {} not found in packages, sysroot(s) nor the missing_dso_whietlist.\n"
+        _print_msg(errors, "{}: {} not found in packages, sysroot(s) nor the missing_dso_whitelist.\n"
                            ".. is this binary repackaging?".
                    format(msg_prelude, needed_dso), verbose=verbose)
 
@@ -1121,6 +1121,9 @@ def check_overlinking_impl(pkg_name, pkg_version, build_str, build_number, subdi
                         install_names = [re.match('^install-name:\s+(.*)$', line) for line in lines]
                         install_names = [insname.groups(1)[0] for insname in install_names]
                         replaced = install_names[0][1:]
+                        if replaced.endswith("'"):
+                            # Some SDKs have install name surrounded by single qoutes
+                            replaced = replaced[1:-1]
                 sysroot_files.append(replaced)
             diffs = set(orig_sysroot_files) - set(sysroot_files)
             if diffs:
